#!/usr/bin/perl

# add pseudo gi numbers to the difinition lines if the lines are not in NCBI FASTA format

use strict;

my $file; # input sequence file name

print "This script is to add pseudo GI numbers to the beginning of all FASTA definition lines. ";
print "You should not run this script if your sequence file is already in NCBI FASTA format. ";
print "However, you have to run this script before using OligoPicker if your FASTA file is not in NCBI format ";
print "(i.e. definition line does not start with 'gi|...'). In this case, please use the output file from this script as ";
print "input sequence file for OligoPicker. This file only modifies the definition lines without making any change to your sequences.\n\n";

print "Name of your non-NCBI FASTA sequence file: ";
while (<>) {
     chomp;
     $file = $_;
     last if -e $_ && -r $_ && -f $_ && -T $_;  # check to see whether file exists, readable, plain file, text file
     print "Error: please check to make sure the file \"$_\" exists and is a readable plain text file.\n";
     print "Please try again. Choose file name: ";
}
print "Selected file to be formatted: $file.\n\n";

open (IN, $file);
open (OUT, ">$file.NCBI");
my $index = 10000;
while (<IN>) {

      s/\s+$//;
      if ($_ =~ /^>/) {
              s/^>//;
              print OUT '>gi|', $index, '|', $_, "\n";
              $index++;
      }
      else {
              print OUT $_, "\n";
      }
}
close(IN);
close(OUT);

print "Definition lines from ", $index - 10000, " sequences have been reformated.\n";
print "Please use $file.NCBI file as the input sequence file for OligoPicker.\n";
print "\n****** Program ended ******\n";



